[][src]Struct pathfinding::matrix::Matrix

pub struct Matrix<C> {
    pub rows: usize,
    pub columns: usize,
    // some fields omitted
}

Matrix of an arbitrary type. Data are stored consecutively in memory, by rows. Raw data can be accessed using as_ref() or as_mut().

Fields

Rows

Columns

Methods

impl<C: Clone> Matrix<C>
[src]

Create new matrix with an initial value.

Create new square matrix with initial value.

Fill with a known value.

Return a copy of a sub-matrix.

Return a copy of a matrix rotated clock-wise a number of times.

Return a copy of a matrix rotated counter-clock-wise a number of times.

Return a copy of the matrix flipped along the vertical axis.

Return a copy of the matrix flipped along the horizontal axis.

Return a copy of the matrix after transposition.

Extend the matrix in place by adding one full row.

Panics

This function panics if the row does not have the expected number of elements.

impl<C: Copy> Matrix<C>
[src]

Replace a slice of the current matrix with the content of another one.

impl<C> Matrix<C>
[src]

Create new matrix from vector values. The first value will be assigned to index (0, 0), the second one to index (0, 1), and so on.

Panics

This function will panic if the number of values does not correspond to the announced size.

Create new square matrix from vector values. The first value will be assigned to index (0, 0), the second one to index (0, 1), and so on.

Panics

This function will panic if the number of values is not a square number.

Create new empty matrix with a predefined number of rows. This is useful to gradually build the matrix and extend it later using extend and does not require a filler element compared to Matrix::new.

Check if a matrix is a square one.

Index in raw data of a given position.

Flip the matrix around the vertical axis.

Flip the matrix around the horizontal axis.

Rotate a square matrix clock-wise a number of times.

Panics

This function panics if the matrix is not square.

Rotate a square matrix counter-clock-wise a number of times.

Panics

This function panics if the matrix is not square.