☰
Module cycle_detection
Functions
?
Module
pathfinding
::
cycle_detection
source
·
[
−
]
Identify a cycle in an infinite sequence.
Functions
brent
Identify a cycle in an infinite sequence using Brent’s algorithm. Return the cycle size, the first element, and the index of first element.
floyd
Identify a cycle in an infinite sequence using Floyd’s algorithm. Return the cycle size, the first element, and the index of first element.