Module pathfinding::directed::bfs
source · Expand description
Compute a shortest path using the breadth-first search algorithm.
Structs
Struct returned by
bfs_reach.Functions
Compute a shortest path using the breadth-first search
algorithm.
Return one of the shortest loop from start to start if it exists,
None otherwise.Visit all nodes that are reachable from a start node. The node will be visited
in BFS order, starting from the
start node and following the order returned
by the successors function.