Count the total number of possible paths to reach a destination.
Functions
- count_
paths - Count the total number of possible paths to reach a destination. There must be no loops in the graph, or the function will overflow its stack.