Module pathfinding::matrix
source · Expand description
Matrix of an arbitrary type and utilities to rotate, transpose, etc.
Modules
Directions usable for
Matrix::in_direction() second argument.Structs
Matrix of an arbitrary type. Data are stored consecutively in
memory, by rows. Raw data can be accessed using
as_ref()
or as_mut().Row iterator returned by
iter() on a matrix.Enums
Format error encountered while attempting to build a Matrix.