[−][src]Struct pathfinding::matrix::Matrix
Matrix of an arbitrary type. Data are stored consecutively in
memory, by rows. Raw data can be accessed using as_ref()
or as_mut().
Fields
rows: usize
Rows
columns: usize
Columns
Methods
impl<C: Clone> Matrix<C>[src]
impl<C: Clone> Matrix<C>pub fn new(rows: usize, columns: usize, value: C) -> Matrix<C>[src]
pub fn new(rows: usize, columns: usize, value: C) -> Matrix<C>Create new matrix with an initial value.
pub fn new_square(size: usize, value: C) -> Matrix<C>[src]
pub fn new_square(size: usize, value: C) -> Matrix<C>Create new square matrix with initial value.
pub fn fill(&mut self, value: C)[src]
pub fn fill(&mut self, value: C)Fill with a known value.
pub fn slice(&self, rows: Range<usize>, columns: Range<usize>) -> Matrix<C>[src]
pub fn slice(&self, rows: Range<usize>, columns: Range<usize>) -> Matrix<C>Return a copy of a sub-matrix.
pub fn rotated_cw(&self, times: usize) -> Matrix<C>[src]
pub fn rotated_cw(&self, times: usize) -> Matrix<C>Return a copy of a matrix rotated clock-wise a number of times.
pub fn rotated_ccw(&self, times: usize) -> Matrix<C>[src]
pub fn rotated_ccw(&self, times: usize) -> Matrix<C>Return a copy of a matrix rotated counter-clock-wise a number of times.
pub fn flipped_lr(&self) -> Matrix<C>[src]
pub fn flipped_lr(&self) -> Matrix<C>Return a copy of the matrix flipped along the vertical axis.
pub fn flipped_ud(&self) -> Matrix<C>[src]
pub fn flipped_ud(&self) -> Matrix<C>Return a copy of the matrix flipped along the horizontal axis.
pub fn transposed(&self) -> Matrix<C>[src]
pub fn transposed(&self) -> Matrix<C>Return a copy of the matrix after transposition.
pub fn extend(&mut self, row: &[C])[src]
pub fn extend(&mut self, row: &[C])Extend the matrix in place by adding one full row.
Panics
This function panics if the row does not have the expected number of elements.
impl<C: Copy> Matrix<C>[src]
impl<C: Copy> Matrix<C>pub fn set_slice(&mut self, pos: &(usize, usize), slice: &Matrix<C>)[src]
pub fn set_slice(&mut self, pos: &(usize, usize), slice: &Matrix<C>)Replace a slice of the current matrix with the content of another one.
impl<C> Matrix<C>[src]
impl<C> Matrix<C>pub fn from_vec(rows: usize, columns: usize, values: Vec<C>) -> Matrix<C>[src]
pub fn from_vec(rows: usize, columns: usize, values: Vec<C>) -> Matrix<C>Create new matrix from vector values. The first value will be assigned to index (0, 0), the second one to index (0, 1), and so on.
Panics
This function will panic if the number of values does not correspond to the announced size.
pub fn square_from_vec(values: Vec<C>) -> Matrix<C>[src]
pub fn square_from_vec(values: Vec<C>) -> Matrix<C>Create new square matrix from vector values. The first value will be assigned to index (0, 0), the second one to index (0, 1), and so on.
Panics
This function will panic if the number of values is not a square number.
pub fn new_empty(columns: usize) -> Matrix<C>[src]
pub fn new_empty(columns: usize) -> Matrix<C>Create new empty matrix with a predefined number of rows. This is useful to gradually build the matrix and extend it later using extend and does not require a filler element compared to Matrix::new.
pub fn is_square(&self) -> bool[src]
pub fn is_square(&self) -> boolCheck if a matrix is a square one.
pub fn idx(&self, i: &(usize, usize)) -> usize[src]
pub fn idx(&self, i: &(usize, usize)) -> usizeIndex in raw data of a given position.
pub fn flip_lr(&mut self)[src]
pub fn flip_lr(&mut self)Flip the matrix around the vertical axis.
pub fn flip_ud(&mut self)[src]
pub fn flip_ud(&mut self)Flip the matrix around the horizontal axis.
pub fn rotate_cw(&mut self, times: usize)[src]
pub fn rotate_cw(&mut self, times: usize)Rotate a square matrix clock-wise a number of times.
Panics
This function panics if the matrix is not square.
pub fn rotate_ccw(&mut self, times: usize)[src]
pub fn rotate_ccw(&mut self, times: usize)Rotate a square matrix counter-clock-wise a number of times.
Panics
This function panics if the matrix is not square.